@@ -14,8 +14,6 @@ import sys
 
 from pkg_resources import get_distribution
 
-sys.path.insert(0, os.path.abspath("./usage"))  # for symplot
-
 # -- Project information -----------------------------------------------------
 project = "AmpForm"
 package = "ampform"
@@ -27,7 +25,13 @@ if os.path.exists(f"../src/{package}/version.py"):
     __release = get_distribution(package).version
     version = ".".join(__release.split(".")[:3])
 
-# -- Generate API skeleton ----------------------------------------------------
+# -- Generate API ------------------------------------------------------------
+sys.path.insert(0, os.path.abspath("."))
+import abbreviate_signature
+import extend_docstrings
+
+extend_docstrings.insert_math()
+
 shutil.rmtree("api", ignore_errors=True)
 subprocess.call(
     " ".join(
@@ -73,6 +77,7 @@ extensions = [
     "sphinx_thebe",
     "sphinx_togglebutton",
     "sphinxcontrib.bibtex",
+    "sphinxcontrib.hep.pdgref",
 ]
 exclude_patterns = [
     "**.ipynb_checkpoints",
@@ -84,6 +89,13 @@ exclude_patterns = [
 # General sphinx settings
 add_module_names = False
 autodoc_default_options = {
+    "exclude-members": ", ".join(
+        [
+            "default_assumptions",
+            "doit",
+            "evaluate",
+        ]
+    ),
     "members": True,
     "undoc-members": True,
     "show-inheritance": True,
@@ -95,13 +107,18 @@ autodoc_default_options = {
         ]
     ),
 }
+autodoc_insert_signature_linebreaks = False
 graphviz_output_format = "svg"
 html_copy_source = True  # needed for download notebook button
+html_css_files = []
+if autodoc_insert_signature_linebreaks:
+    html_css_files.append("linebreaks-api.css")
 html_favicon = "_static/favicon.ico"
 html_show_copyright = False
 html_show_sourcelink = False
 html_show_sphinx = False
 html_sourcelink_suffix = ""
+html_static_path = ["_static"]
 html_theme = "sphinx_book_theme"
 html_theme_options = {
     "repository_url": f"https://github.com/ComPWA/{repo_name}",
@@ -130,21 +147,9 @@ default_role = "py:obj"
 primary_domain = "py"
 nitpicky = True  # warn if cross-references are missing
 nitpick_ignore = [
-    ("py:class", "EdgeType"),
-    ("py:class", "NoneType"),
-    ("py:class", "StateTransitionGraph"),
-    ("py:class", "ValueType"),
-    ("py:class", "a set-like object providing a view on D's items"),
-    ("py:class", "a set-like object providing a view on D's keys"),
-    ("py:class", "an object providing a view on D's values"),
     ("py:class", "ipywidgets.widgets.widget_float.FloatSlider"),
     ("py:class", "ipywidgets.widgets.widget_int.IntSlider"),
-    ("py:class", "mpl_interactions.controller.Controls"),
-    ("py:class", "numpy.typing._array_like._SupportsArray"),
-    ("py:class", "numpy.typing._dtype_like._DTypeDict"),
-    ("py:class", "numpy.typing._dtype_like._SupportsDType"),
     ("py:class", "typing_extensions.Protocol"),
-    ("py:obj", "ampform.amplitude.helicity.ValueType"),
 ]
 
 # Intersphinx settings
@@ -182,6 +187,9 @@ copybutton_prompt_text = r">>> |\.\.\. "  # doctest
 
 # Settings for linkcheck
 linkcheck_anchors = False
+linkcheck_ignore = [
+    "https://doi.org/10.1093/ptep/ptaa104",
+]
 
 # Settings for myst_nb
 execution_timeout = -1
@@ -212,7 +220,23 @@ myst_enable_extensions = [
     "colon_fence",
     "dollarmath",
     "smartquotes",
+    "substitution",
 ]
+BINDER_LINK = (
+    f"https://mybinder.org/v2/gh/ComPWA/{repo_name}/stable?filepath=docs/usage"
+)
+COLAB_LINK = (
+    f"https://colab.research.google.com/github/ComPWA/{repo_name}/blob/stable"
+)
+myst_substitutions = {
+    "run_interactive": f"""
+```{{margin}}
+Run this notebook in [Google Colab]({COLAB_LINK}), [Binder]({BINDER_LINK}), or
+{{ref}}`locally on Jupyter Lab <pwa:develop:Jupyter Notebooks>` to
+interactively modify the parameters.
+```
+"""
+}
 myst_update_mathjax = False
 
 # Settings for Thebe cell output
@@ -242,14 +266,21 @@ from pybtex.style.template import (
     sentence,
     words,
 )
+from sphinxcontrib.bibtex.style.referencing import BracketStyle
 from sphinxcontrib.bibtex.style.referencing.author_year import (
     AuthorYearReferenceStyle,
 )
 
+no_brackets = BracketStyle(
+    left="",
+    right="",
+)
+
 
 @dataclasses.dataclass
 class NoCommaReferenceStyle(AuthorYearReferenceStyle):
     author_year_sep: Union["BaseText", str] = " "
+    bracket_parenthetical: BracketStyle = no_brackets
 
 
 sphinxcontrib.bibtex.plugin.register_plugin(
