@@ -73,7 +73,7 @@ class TestEpemToDmD0Pip:
             final_state=[("D0", [0]), ("D-", [0]), ("pi+", [0])],
             allowed_intermediate_particles=["D(2)*(2460)+"],
             allowed_interaction_types="em",
-            particles=particles,
+            particle_db=particles,
         )
 
         amplitude_model = get_builder(result).generate()
@@ -86,7 +86,7 @@ class TestEpemToDmD0Pip:
         return sp.re(full_model)
 
     @pytest.mark.parametrize(
-        "angular_variables, expected_distribution_function",  # type: ignore
+        ("angular_variables", "expected_distribution_function"),
         [
             (  # cos(theta) distribution from epem decay
                 "theta_1+2",
@@ -177,7 +177,7 @@ class TestD1ToD0PiPi:
         return sp.re(full_model)
 
     @pytest.mark.parametrize(
-        "angular_variables, expected_distribution_function",  # type: ignore
+        ("angular_variables", "expected_distribution_function"),
         [
             (  # theta distribution from D1 decay
                 "theta_1+2",
